# Building blocks

This folder contains some basic examples of Tesseract usage, tested regularly to ensure they work with the latest version of Tesseract.

> [!NOTE]
> These are not meant to be full-featured applications, but rather minimal examples that test and demonstrate specific features of Tesseract. For more comprehensive examples, see the [example gallery](https://docs.pasteurlabs.ai/projects/tesseract-core/latest/content/examples/example_gallery.html), [demo gallery](https://docs.pasteurlabs.ai/projects/tesseract-core/latest/content/demo/demo.html), and [community showcases](https://si-tesseract.discourse.group/c/showcase/11).
